# Change log

## [0.4.0] - 2023-03-12

### Added
- n/a

### Changed
- changed package manager

## [0.3.2] - 2022-10-10

### Added
- n/a

### Changed
- n/a

## [0.3.1] - 2022-06-15

### Added
- n/a

### Changed
- n/a

## [0.2.1] - 2021-08-01

### Added
- 

### Changed
- `get_current_trading_code()`

## [0.2.0] - 2021-06-01

### Added
- added get_market_depth_data
- added get_dsex_data
- added 'dse.com.bd' as redundant 

### Changed
- Changed documentation
- changed get_agm_news 
- changed get_all_news


## [0.1.4] - 2020-08-22

### Added
- added get_market_inf_more_data

### Changed
- Changed documentation


## [0.1.3] - 2020-08-20

### Added
- html5lib
- added get params

### Changed
- post request to get


## [0.1.2] - 2020-05-21

### Added
- modified index declaration


## [0.1.1] - 2020-05-20

### Added
- modified index declaration


## [0.1.0] - 2020-04-08

### Added
- added git tag
- `VERSION.txt`

### Changed
- `setup.py`
- `HISTORY.md` to `CHANGELOG.md`


## [0.0.1] - 2020-04-06

### Added
- `get_hist_data(), get_current_trade_data()`
- `HISTORY.md`
